@@ -344,6 +344,7 @@ function insert_table($data) {
 		$icolumns = implode(',', $icoumns_array);
 		$ivalues = implode(',', $ivalues_array);
 		$sql = "INSERT INTO $this->current_table ($icolumns) VALUES ($ivalues)";
+		//echo "sql=$sql<br>\n";
 		$result[$this->current_table]['sql'] = $sql;
 		try {
 			if($this->use_pdo) {
@@ -603,7 +604,11 @@ function select_table($condition='',$fields='*') {
 function count_rows($condition='') {
 	if(!isset($this->pdo)) $this->connect_pdo($this->__dsn);
 	foreach($this->bind_column2form as $table=>$columns) {
-		$sql = "SELECT count(id) FROM $table $condition";
+		if(strpos($condition,'join')!==false or strpos($condition,'JOIN')!==false) {
+			$sql = "SELECT count($table.id) FROM $table $condition";
+		} else {
+			$sql = "SELECT count(id) FROM $table $condition";
+		}
 		try {
 			if($this->use_pdo) {
 				$stmt = $this->pdo->prepare($sql);
@@ -851,12 +856,14 @@ function display_table_value($table_values) {
 			foreach($row as $column=>$value) {
 				if($qs_type = $this->data_view[$column]['qs_type']) {
 					$body = call_user_func(array($this,'display_'.$qs_type.'_value'),$column,$value);
+				} else {
+					$body = $value;
+				}
 					$new_row[$column]['label'] = $this->data_view[$column]['label'];
 					$new_row[$column]['type'] = $this->data_view[$column]['type'];
 					$new_row[$column]['qs_type'] = $this->data_view[$column]['qs_type'];
 					$new_row[$column]['value'] = $value;
 					$new_row[$column]['body'] = $body;
-				}
 			} 
 			$sequence++;
 			$display_table[$key] = $new_row;
