@@ -88,7 +88,7 @@ function bind_data_view($data_view_file) {
 		$current_logic = array($this,$hqf_type.'_element');
 		$this->form_element[$column] = call_user_func($current_logic,$method_pram);
 		$this->data_view[$column] = $method_pram;
-		if($attributes['default']) {
+		if(isset($attributes['default'])) {
 			$this->setDefaults(array($column=>$attributes['default']));
 		}
 		if($attributes['default_list']=='start') {
