@@ -657,6 +657,46 @@ public function new_data_set($set_name,$params=array(),$cache=false) {
 	return $data_set;
 }
 
+/**
+ *	Quick build DataView object and bind data_view for Search form.
+ *
+ *	@access	public
+ *	@param	array $params From's option
+ *		string $params['method'] (optional)Form's method defaults to 'POST'
+ *		string $params['action (optional)Form's action
+ *		string $params['target (optional)Form's target defaults to '_self'
+ *		string $params['attributes (optional)Extra attributes for <form> tag
+ *	@param	string $set_name DataSet form's name and data_view file's name and data_set file's name.
+ *	@return	object DataSet object.
+ */
+public function new_search_obj($set_name,$params=array(),$cache=false) {
+	if($cache and $this->memcached) {
+		$DATA_VIEW_CACHE = $this->memcache->get('DATA_VIEW_'.$set_name);
+	} elseif($cache and function_exists(apc_fetch)) {
+		$DATA_VIEW_CACHE = unserialize(apc_fetch('DATA_VIEW_'.$set_name));
+	}
+	if(is_object($DATA_VIEW_CACHE)) {
+		$data_view = $DATA_VIEW_CACHE;
+		$this->memcache_use .= $set_name." : get from cache.\n";
+	} else {
+		$data_view = $this->new_data_obj($set_name,$params);
+		$data_view->bind_data_view($set_name.'.view.conf');
+		$this->set_qs_status('SEND');
+		$data_view->set_button_label('send','');
+		$data_view->bind_button_control();
+		$this->memcache_use .= $set_name." : generated.\n";
+		if($cache and $this->memcached) {
+			$result = $this->memcache->set('DATA_VIEW_'.$set_name,$data_view,
+					$this->memcache_compress,$this->memcache_expire);
+		} elseif($cache and function_exists(apc_store)) {
+			$result = apc_store('DATA_VIEW_'.$set_name,serialize($data_view));
+		}
+	}
+
+	return $data_view;
+}
+
+
 /**
  *	Create Quicty::QT_Auth object.
  *	AuthSet object can provides authentication system with easy settings.
