@@ -48,10 +48,13 @@ function request_or_session($value_name) {
 
 function quicty_base_url() {
 	$self = $_SERVER['PHP_SELF'];
-	if(substr($self,-9)=='index.php')
-		$self = substr($self,0,-9);
-	if(substr($self,-1)=='/')
-		$self = substr($self,0,-1);
+	//echo "self=$self<br>";
+	if(substr($self,-10)=='/index.php')
+		$self = substr($self,0,-10);
+	else
+		$self = '';
+	//if(substr($self,-1)=='/')
+	//	$self = substr($self,0,-1);
 	return $self;
 }
 
@@ -217,6 +220,37 @@ function copy_files($source,$target_dir,$copy_dir=false,$permit=0644) {
 		return $d;
 	}
 
+	function parse_csv($buffer) {
+		if(!trim($buffer)) return false;
+		$data = array();
+		$word = '';
+		$quote = false;
+		$len = mb_strlen($buffer);
+		for($i=0;$i<$len;$i++) {
+			$char = mb_substr($buffer,$i,1);
+			switch($char) {
+				case ',':
+					if($quote) {
+						$word .= $char;
+					} else {
+						$data[] = $word;
+						$word = '';
+					}
+					break;
+				case '"':
+					if($quote)
+						$quote = false;
+					else
+						$quote = true;
+					break;
+				default:
+					$word .= $char;
+			}
+		}
+		$data[] = $word;
+		return $data;
+	}
+
 $html_quickform_datatype = array(
 	'advcheckbox'=>array('name'=>'string','label'=>'string','text'=>'string','attr'=>'property_array','values'=>'property_array'),
 	'button'=>array('name'=>'string','value'=>'string','attr'=>'property_array'),
